@@ -1,24 +1,24 @@
 /*****************************************************************************
  * gen_pmt.c: PMT generator
  *----------------------------------------------------------------------------
- * Copyright (C) 2001-2011 VideoLAN
- * $Id$
+ * (c)2001-2002 VideoLAN
+ * $Id: gen_pmt.c 149 2007-10-11 06:47:59Z jpsaman $
  *
  * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  *----------------------------------------------------------------------------
  *
@@ -28,7 +28,6 @@
 #include "config.h"
 
 #include <stdio.h>
-#include <stdbool.h>
 
 #if defined(HAVE_INTTYPES_H)
 #include <inttypes.h>
@@ -36,8 +35,6 @@
 #include <stdint.h>
 #endif
 
-#include <sys/types.h>
-
 /* the libdvbpsi distribution defines DVBPSI_DIST */
 #ifdef DVBPSI_DIST
 #include "../src/dvbpsi.h"
@@ -55,13 +52,12 @@
 /*****************************************************************************
  * writePSI
  *****************************************************************************/
-static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
+void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
 {
   p_packet[0] = 0x47;
 
   while(p_section)
   {
-    size_t i_bytes_written = 0;
     uint8_t* p_pos_in_ts;
     uint8_t* p_byte = p_section->p_data;
     uint8_t* p_end =   p_section->p_payload_end
@@ -77,12 +73,8 @@ static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
       *(p_pos_in_ts++) = *(p_byte++);
     while(p_pos_in_ts < p_packet + 188)
       *(p_pos_in_ts++) = 0xff;
-    i_bytes_written = fwrite(p_packet, 1, 188, stdout);
-    if(i_bytes_written == 0)
-    {
-      fprintf(stderr,"eof detected ... aborting\n");
-      return;
-    }
+    fwrite(p_packet, 1, 188, stdout);
+
     p_packet[3] = (p_packet[3] + 1) & 0x0f;
 
     while(p_byte < p_end)
@@ -96,12 +88,7 @@ static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
         *(p_pos_in_ts++) = *(p_byte++);
       while(p_pos_in_ts < p_packet + 188)
         *(p_pos_in_ts++) = 0xff;
-      i_bytes_written = fwrite(p_packet, 1, 188, stdout);
-      if(i_bytes_written == 0)
-      {
-        fprintf(stderr,"eof detected ... aborting\n");
-        return;
-      }
+      fwrite(p_packet, 1, 188, stdout);
 
       p_packet[3] = (p_packet[3] + 1) & 0x0f;
     }
@@ -110,18 +97,6 @@ static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
   }
 }
 
-static void message(dvbpsi_t *handle, const dvbpsi_msg_level_t level, const char* msg)
-{
-    switch(level)
-    {
-        case DVBPSI_MSG_ERROR: fprintf(stderr, "Error: "); break;
-        case DVBPSI_MSG_WARN:  fprintf(stderr, "Warning: "); break;
-        case DVBPSI_MSG_DEBUG: fprintf(stderr, "Debug: "); break;
-        default: /* do nothing */
-            return;
-    }
-    fprintf(stderr, "%s\n", msg);
-}
 
 /*****************************************************************************
  * main
@@ -136,39 +111,35 @@ int main(int i_argc, char* pa_argv[])
   dvbpsi_psi_section_t* p_section3, * p_section4;
   dvbpsi_psi_section_t* p_section5, * p_section6;
 
-  dvbpsi_t *p_dvbpsi = dvbpsi_new(&message, DVBPSI_MSG_DEBUG);
-  if (p_dvbpsi == NULL)
-      return 1;
-
   /* PMT generation */
-  dvbpsi_pmt_init(&pmt, 12, 0, 0, 42);
-  dvbpsi_pmt_descriptor_add(&pmt, 12, 26, data);
-  dvbpsi_pmt_descriptor_add(&pmt, 42, 12, data + 12);
-  dvbpsi_pmt_descriptor_add(&pmt, 2, 1, data + 4);
-  dvbpsi_pmt_descriptor_add(&pmt, 0, 4, data + 7);
-  p_es = dvbpsi_pmt_es_add(&pmt, 12, 42);
-  dvbpsi_pmt_es_descriptor_add(p_es, 12, 26, data);
-  dvbpsi_pmt_es_descriptor_add(p_es, 42, 12, data + 12);
-  dvbpsi_pmt_es_descriptor_add(p_es, 2, 1, data + 4);
-  dvbpsi_pmt_es_descriptor_add(p_es, 0, 4, data + 7);
+  dvbpsi_InitPMT(&pmt, 12, 0, 0, 42);
+  dvbpsi_PMTAddDescriptor(&pmt, 12, 26, data);
+  dvbpsi_PMTAddDescriptor(&pmt, 42, 12, data + 12);
+  dvbpsi_PMTAddDescriptor(&pmt, 2, 1, data + 4);
+  dvbpsi_PMTAddDescriptor(&pmt, 0, 4, data + 7);
+  p_es = dvbpsi_PMTAddES(&pmt, 12, 42);
+  dvbpsi_PMTESAddDescriptor(p_es, 12, 26, data);
+  dvbpsi_PMTESAddDescriptor(p_es, 42, 12, data + 12);
+  dvbpsi_PMTESAddDescriptor(p_es, 2, 1, data + 4);
+  dvbpsi_PMTESAddDescriptor(p_es, 0, 4, data + 7);
 
-  p_section1 = dvbpsi_pmt_sections_generate(p_dvbpsi, &pmt);
+  p_section1 = dvbpsi_GenPMTSections(&pmt);
   pmt.b_current_next = 1;
-  p_section2 = dvbpsi_pmt_sections_generate(p_dvbpsi, &pmt);
+  p_section2 = dvbpsi_GenPMTSections(&pmt);
 
   pmt.i_version = 1;
 
   pmt.b_current_next = 0;
-  p_section3 = dvbpsi_pmt_sections_generate(p_dvbpsi, &pmt);
+  p_section3 = dvbpsi_GenPMTSections(&pmt);
   pmt.b_current_next = 1;
-  p_section4 = dvbpsi_pmt_sections_generate(p_dvbpsi, &pmt);
+  p_section4 = dvbpsi_GenPMTSections(&pmt);
 
   pmt.i_version = 2;
 
   pmt.b_current_next = 0;
-  p_section5 = dvbpsi_pmt_sections_generate(p_dvbpsi, &pmt);
+  p_section5 = dvbpsi_GenPMTSections(&pmt);
   pmt.b_current_next = 1;
-  p_section6 = dvbpsi_pmt_sections_generate(p_dvbpsi, &pmt);
+  p_section6 = dvbpsi_GenPMTSections(&pmt);
 
   /* TS packets generation */
   packet[0] = 0x47;
@@ -191,8 +162,8 @@ int main(int i_argc, char* pa_argv[])
   dvbpsi_DeletePSISections(p_section5);
   dvbpsi_DeletePSISections(p_section6);
 
-  dvbpsi_pmt_empty(&pmt);
-  dvbpsi_delete(p_dvbpsi);
+  dvbpsi_EmptyPMT(&pmt);
+
   return 0;
 }
 
